import React from 'react';
import { LiveRegionProps } from './types';
/**
 * Render an ARIA live region as a React Portal. Changing the `children` of this
 * component will result in
 * 1. Render the live region.
 * 2. Wait a moment so that AT can start monitoring it for changes.
 * 3. Update it with a duplicate of the new children to ensure that screen
 * reader users will perceive the change in content.
 * 4. Remove the live region a moment later.
 *
 * Reference:
 * - [MDN - ARIA Live Regions](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Live_Regions)
 */
export declare const LiveRegion: React.FunctionComponent<LiveRegionProps>;
/**
 * Monitor an element for content changes. Returns the element's changed content,
 * which should be passed to a `LiveRegion` as `children` to ensure that screen
 * reader users will be notified of the change.
 */
export declare const useContentMonitor: (el: HTMLElement | null, children: React.ReactNode) => React.ReactNode;
//# sourceMappingURL=LiveRegion.d.ts.map