import React from 'react';
export interface Header {
    colId: string;
    el: HTMLElement;
    text: string;
}
export interface HeadersState {
    headers: Header[];
    registerHeader: (colId: string, el: HTMLElement) => void;
}
export declare const HeadersContext: React.Context<HeadersState>;
/**
 * Registers the headers of the table.
 * This has been introduced to support rendering the text of the header alongside
 * the content of the Table Cells for XS breakpoints.
 */
export declare const HeadersContextProvider: ({ children }: {
    children: React.ReactNode;
}) => React.JSX.Element;
/**
 * Returns the header text for the column identified with the given `colIdx`.
 * Returns empty string if not found.
 */
export declare function useHeaderFor(colIdx: number): string;
/**
 * Returns the `colIdx` (Column Index) that corresponds to the given
 * `colId`.
 * Returns `-1` if not found.
 */
export declare function useFindColIdx(): (colId: string) => number;
/**
 * Returns the text context of the registered headers.
 */
export declare function useHeadersText(): string[];
/**
 * Registers the header passed in `th`.
 */
export declare function useRegisterHeader(colId: string, th: React.RefObject<HTMLTableCellElement>): void;
//# sourceMappingURL=HeadersContext.d.ts.map