import React from 'react';
import { ColorScheme } from '../../utilities/theme';
export type ThemeProviderProps = React.PropsWithChildren<{
    /**
     * The desired color scheme.
     *
     * - `"light"` – dark text on light background.
     * - `"dark"` – light text on dark background.
     * - `"inverse"` – the opposite color scheme from the parent `<ThemeProvider>`.
     * Cannot be used on the root `<ThemeProvider>`.
     * - `undefined` – use the user's preferred color scheme. If `ignoreOSColorScheme`
     * is `true`, `"light"` will be used as a fallback.
     *
     * Reference: [prefers-color-scheme media query](https://drafts.csswg.org/mediaqueries-5/#prefers-color-scheme).
     */
    colorScheme?: ColorScheme | 'inverse';
    /** If set, the user's operating system color scheme setting will be ignored. */
    ignoreOSColorScheme?: boolean;
    /**
     * A callback function that will trigger any time the `colorScheme` changes.
     * Use to update the color scheme store when it's changed by the user.
     */
    onColorSchemeChange?: (scheme: ColorScheme) => void;
}>;
/** A context provider for theming the Norton Design System. */
export declare const ThemeProvider: React.FunctionComponent<ThemeProviderProps>;
//# sourceMappingURL=index.d.ts.map